# Contributing to Matplotlib using GitHub codespaces

* For a general overview of contributing to Matplotlib, see https://matplotlib.org/devdocs/devel/index.html

* For instructions on how to submit Pull Requests using GitHub codespaces, see https://matplotlib.org/devdocs/devel/contribute.html#contributing-code

* For instructions on running tests to verify your changes, see https://matplotlib.org/devdocs/devel/testing.html

* For instructions on building the Matplotlib documentation, see https://matplotlib.org/devdocs/devel/document.html#documenting-matplotlib
